@@ -5,7 +5,7 @@ const parse = require("../lib/parser.js");
 
 describe("base64.json", () => {
   for (const [input, expectedBodyBytes] of base64TestCases) {
-    const dataURL = "data:;base64," + input;
+    const dataURL = `data:;base64,${input}`;
     test(dataURL, () => {
       const result = parse(dataURL);
 
@@ -17,8 +17,8 @@ describe("base64.json", () => {
         expect(result.mimeType.parameters.size).toEqual(1);
         expect(result.mimeType.parameters.get("charset")).toEqual("US-ASCII");
 
-        expect(result.body.constructor).toEqual(Buffer);
-        expect(result.body).toEqual(Buffer.from(expectedBodyBytes));
+        expect(result.body.constructor).toEqual(Uint8Array);
+        expect(result.body).toEqual(Uint8Array.from(expectedBodyBytes));
       }
     });
   }
@@ -34,8 +34,8 @@ describe("data-urls.json", () => {
       } else {
         expect(result.mimeType.toString()).toEqual(expectedMIMEType);
 
-        expect(result.body.constructor).toEqual(Buffer);
-        expect(result.body).toEqual(Buffer.from(expectedBodyBytes));
+        expect(result.body.constructor).toEqual(Uint8Array);
+        expect(result.body).toEqual(Uint8Array.from(expectedBodyBytes));
       }
     });
   }
